==> modx-2.0.7-pl-ja.zip: modx-2.0.7-pl-ja/core/lexicon/ja/permissions.inc.php <==
<?php
/**
 * Permissions Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 */
$_lang['perm.about_desc'] = '情報のページ';
$_lang['perm.access_permissions_desc'] = 'アクセス権限関係のページとアクション';
$_lang['perm.actions_desc'] = 'アクションのページ';
$_lang['perm.add_children_desc'] = '指定されたリソースのサブリソースを追加する';
$_lang['perm.change_password_desc'] = 'パスワードを変更することができます';
$_lang['perm.change_profile_desc'] = 'プロフィールを変更することができます';
$_lang['perm.charsets_desc'] = '文字セットの一覧を表示';
$_lang['perm.class_map_desc'] = 'To view a list of classes in the Class Map.';
$_lang['perm.components_desc'] = 'To view the Components menu.';
$_lang['perm.content_types_desc'] = 'コンテンツタイプのページ';
$_lang['perm.copy_desc'] = 'The ability to copy an object.';
$_lang['perm.countries_desc'] = '国の一覧を表示する';
$_lang['perm.create_desc'] = '新しいオブジェクトでの基本的な「作成」動作';
$_lang['perm.credits_desc'] = 'クレジットを表示する';
$_lang['perm.customize_forms_desc'] = 'フォームカスタマイズページの表示と管理';
$_lang['perm.database_desc'] = 'システム情報のページ';
$_lang['perm.database_truncate_desc'] = 'データベーステーブルを切り詰める機能';
$_lang['perm.delete_desc'] = 'オブジェクトでの基本的な「削除」動作';
$_lang['perm.delete_category_desc'] = 'カテゴリーを削除する';
$_lang['perm.delete_chunk_desc'] = 'チャンクを削除する';
$_lang['perm.delete_context_desc'] = 'コンテキストを削除する';
$_lang['perm.delete_document_desc'] = 'リソースを削除する';
$_lang['perm.delete_eventlog_desc'] = 'イベントログを空にする';
$_lang['perm.delete_plugin_desc'] = 'プラグインを削除する';
$_lang['perm.delete_propertyset_desc'] = 'プロパティセットを削除する';
$_lang['perm.delete_role_desc'] = 'ロールを削除する';
$_lang['perm.delete_snippet_desc'] = 'スニペットを削除する';
$_lang['perm.delete_template_desc'] = 'テンプレートを削除する';
$_lang['perm.delete_tv_desc'] = 'テンプレート変数を削除する';
$_lang['perm.delete_user_desc'] = 'ユーザーを削除する';
$_lang['perm.directory_chmod_desc'] = '物理フォルダの権限を変更する';
$_lang['perm.directory_create_desc'] = '物理フォルダを作成する';
$_lang['perm.directory_list_desc'] = '物理フォルダのサブフォルダ一覧';
$_lang['perm.directory_remove_desc'] = '物理フォルダを削除する';
$_lang['perm.directory_update_desc'] = '物理フォルダの名前を変更する';
$_lang['perm.edit_category_desc'] = 'カテゴリを編集する';
$_lang['perm.edit_chunk_desc'] = 'チャンクを編集する';
$_lang['perm.edit_context_desc'] = 'コンテキストを編集する';
$_lang['perm.edit_document_desc'] = 'リソースを編集する';
$_lang['perm.edit_locked_desc'] = 'ロックの上書きを許可し、ロックされたリソースを編集する';
$_lang['perm.edit_plugin_desc'] = 'プラグインを編集する';
$_lang['perm.edit_propertyset_desc'] = 'プロパティセットを編集する';
$_lang['perm.edit_role_desc'] = 'ロールを編集する';
$_lang['perm.edit_snippet_desc'] = 'スニペットを編集する';
$_lang['perm.edit_template_desc'] = 'テンプレートを編集する';
$_lang['perm.edit_tv_desc'] = 'テンプレート変数を編集する';
$_lang['perm.edit_user_desc'] = 'ユーザーを編集する';
$_lang['perm.element_tree_desc'] = '左のナビゲーションにエレメントのツリーを表示する機能';
$_lang['perm.empty_cache_desc'] = 'サイトのキャッシュを空にする';
$_lang['perm.error_log_erase_desc'] = 'エラーログを消す';
$_lang['perm.error_log_view_desc'] = 'エラーログを表示する';
$_lang['perm.export_static_desc'] = 'サイトを静的HTMLにエクスポートする';
$_lang['perm.file_list_desc'] = '指定した物理フォルダのファイルを一覧にする';
$_lang['perm.file_manager_desc'] = 'ファイルマネージャー機能を使用する';
$_lang['perm.file_remove_desc'] = '物理ファイルを削除する';
$_lang['perm.file_tree_desc'] = '左のナビゲーションにファイルのツリーを表示する';
$_lang['perm.file_update_desc'] = '物理ファイルのコンテンツを更新する';
$_lang['perm.file_upload_desc'] = 'フォルダへファイルをアップロードする';
$_lang['perm.file_view_desc'] = 'ファイルのコンテンツを表示する';
$_lang['perm.flush_sessions_desc'] = 'サイトのセッションを削除することが可能';
$_lang['perm.frames_desc'] = '全てにおいてMODx管理画面UIを使用する';
$_lang['perm.help_desc'] = 'ヘルプページを表示する';
$_lang['perm.home_desc'] = 'ウェルカムページ(ダッシュボード)を表示する';
$_lang['perm.import_static_desc'] = 'インポートページを表示・利用する';
$_lang['perm.languages_desc'] = '語彙の言語を表示・編集する';
$_lang['perm.lexicons_desc'] = '語彙トピックと多言語管理の機能を表示・編集する';
$_lang['perm.list_desc'] = 'オブジェクトを「一覧」にする基本的な権限。一覧とはオブジェクトを集める手段を意味する。';
$_lang['perm.load_desc'] = 'オブジェクトを「読み込む」基本的な権限、または全てのインスタンスを返却できる権限。';
$_lang['perm.logout_desc'] = 'ログアウトできます';
$_lang['perm.logs_desc'] = 'エラーログや管理画面操作ログなどを表示する';
$_lang['perm.menus_desc'] = 'トップメニューのアイテムを編集・保存する';
$_lang['perm.messages_desc'] = 'メッセージの送信または表示を行う';
$_lang['perm.move_desc'] = 'オブジェクトでの基本的な「移動」動作';
$_lang['perm.namespaces_desc'] = 'ネームスペースを表示・編集する';
$_lang['perm.new_category_desc'] = '新しいカテゴリを作成する';
$_lang['perm.new_chunk_desc'] = '新しいチャンクを作成する';
$_lang['perm.new_context_desc'] = '新しいコンテキストを作成する';
$_lang['perm.new_document_desc'] = '新しいリソースを作成する';
$_lang['perm.new_document_in_root_desc'] = 'rootレベルでリソースを作成可能';
$_lang['perm.new_plugin_desc'] = '新しいプラグインを作成する';
$_lang['perm.new_propertyset_desc'] = '新しいプロパティセットを作成する';
$_lang['perm.new_role_desc'] = '新しいロールを作成する';
$_lang['perm.new_snippet_desc'] = '新しいスニペットを作成する';
$_lang['perm.new_template_desc'] = '新しいテンプレートを作成する';
$_lang['perm.new_tv_desc'] = '新しいテンプレート変数を作成する';
$_lang['perm.new_user_desc'] = '新しいユーザーを作成する';
$_lang['perm.packages_desc'] = 'パッケージ管理システムで、転送パッケージを使用する';
$_lang['perm.property_sets_desc'] = 'プロパティとプロパティセットの表示と編集を行う';
$_lang['perm.providers_desc'] = 'サイト上でプロバイダーの表示と編集を行う';
$_lang['perm.publish_desc'] = 'オブジェクトでの基本的な「公開」動作';
$_lang['perm.publish_document_desc'] = 'リソースを公開または非公開にする';
$_lang['perm.purge_deleted_desc'] = 'ゴミ箱を空にする';
$_lang['perm.remove_desc'] = 'オブジェクトを削除する基本的な権限';
$_lang['perm.remove_locks_desc'] = 'サイト上に存在している全てのロックを削除する';
$_lang['perm.resource_tree_desc'] = '左のナビゲーションにリソースのツリーを表示する';
$_lang['perm.save_desc'] = 'オブジェクトの基本的な保存権限';
$_lang['perm.save_category_desc'] = 'カテゴリを保存する';
$_lang['perm.save_chunk_desc'] = 'チャンクを保存する';
$_lang['perm.save_context_desc'] = 'コンテキストを保存する';
$_lang['perm.save_document_desc'] = 'リソースを保存する';
$_lang['perm.save_plugin_desc'] = 'プラグインを保存する';
$_lang['perm.save_propertyset_desc'] = 'プロパティセットを保存する';
$_lang['perm.save_role_desc'] = 'ロールを保存する';
$_lang['perm.save_snippet_desc'] = 'スニペットを保存する';
$_lang['perm.save_template_desc'] = 'テンプレートを保存する';
$_lang['perm.save_tv_desc'] = 'テンプレート変数を保存する';
$_lang['perm.save_user_desc'] = 'ユーザーを保存する';
$_lang['perm.search_desc'] = '検索ページを使用する';
$_lang['perm.settings_desc'] = 'システム設定の表示と編集を行う';
$_lang['perm.steal_lock_desc'] = 'リソースからロックを「横取り」または削除する';
$_lang['perm.steal_locks_desc'] = 'リソースの現在のロックをうがわいてロックを「横取り」する';
$_lang['perm.undelete_desc'] = 'オブジェクトを復活する基本的な権限';
$_lang['perm.undelete_document_desc'] = 'リソースを復活する';
$_lang['perm.unlock_element_properties_desc'] = 'エレメントでデフォルトのプロパティを編集可能';
$_lang['perm.unpublish_desc'] = 'リソースを非公開にする';
$_lang['perm.unpublish_document_desc'] = 'リソースを非公開にする';
$_lang['perm.view_desc'] = 'オブジェクトを表示する基本的な権限';
$_lang['perm.view_category_desc'] = 'カテゴリを表示する';
$_lang['perm.view_chunk_desc'] = 'チャンクを表示する';
$_lang['perm.view_context_desc'] = 'コンテキストを表示する';
$_lang['perm.view_document_desc'] = 'リソースを表示する';
$_lang['perm.view_element_desc'] = 'エレメントまたはエレメントクラスの一覧を取得する';
$_lang['perm.view_eventlog_desc'] = 'イベントログを表示する';
$_lang['perm.view_offline_desc'] = 'ステータスがオフラインのときにサイトを表示することが可能';
$_lang['perm.view_plugin_desc'] = 'プラグインを表示する';
$_lang['perm.view_propertyset_desc'] = 'プロパティセットを表示する';
$_lang['perm.view_role_desc'] = 'ロールを表示する';
$_lang['perm.view_snippet_desc'] = 'スニペットを表示する';
$_lang['perm.view_sysinfo_desc'] = 'システム情報ページを表示する';
$_lang['perm.view_template_desc'] = 'テンプレートを表示する';
$_lang['perm.view_tv_desc'] = 'テンプレート変数を表示する';
$_lang['perm.view_unpublished_desc'] = '非公開のリソースを表示する';
$_lang['perm.view_user_desc'] = 'ユーザーを表示する';
$_lang['perm.workspaces_desc'] = 'パッケージ管理を利用する';

==> modx-2.1.4-pl-ja.zip: modx-2.1.4-pl-ja/core/lexicon/ja/permissions.inc.php <==
<?php
/**
 * Permissions Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 */
$_lang['perm.about_desc'] = '情報のページ';
$_lang['perm.access_permissions_desc'] = 'アクセス権限関係のページとアクション';
$_lang['perm.actions_desc'] = 'アクションのページ';
$_lang['perm.add_children_desc'] = '指定されたリソースのサブリソースを追加する';
$_lang['perm.change_password_desc'] = 'パスワードを変更することができます';
$_lang['perm.change_profile_desc'] = 'プロフィールを変更することができます';
$_lang['perm.charsets_desc'] = '文字セットの一覧を表示';
$_lang['perm.class_map_desc'] = 'To view a list of classes in the Class Map.';
$_lang['perm.components_desc'] = 'To view the Components menu.';
$_lang['perm.content_types_desc'] = 'コンテンツタイプのページ';
$_lang['perm.copy_desc'] = 'The ability to copy an object.';
$_lang['perm.countries_desc'] = '国の一覧を表示する';
$_lang['perm.create_desc'] = '新しいオブジェクトでの基本的な「作成」動作';
$_lang['perm.credits_desc'] = 'クレジットを表示する';
$_lang['perm.customize_forms_desc'] = 'フォームカスタマイズページの表示と管理';
$_lang['perm.database_desc'] = 'システム情報のページ';
$_lang['perm.database_truncate_desc'] = 'データベーステーブルを切り詰める機能';
$_lang['perm.delete_desc'] = 'オブジェクトでの基本的な「削除」動作';
$_lang['perm.delete_category_desc'] = 'カテゴリーを削除する';
$_lang['perm.delete_chunk_desc'] = 'チャンクを削除する';
$_lang['perm.delete_context_desc'] = 'コンテキストを削除する';
$_lang['perm.delete_document_desc'] = 'リソースを削除する';
$_lang['perm.delete_eventlog_desc'] = 'イベントログを空にする';
$_lang['perm.delete_plugin_desc'] = 'プラグインを削除する';
$_lang['perm.delete_propertyset_desc'] = 'プロパティセットを削除する';
$_lang['perm.delete_role_desc'] = 'ロールを削除する';
$_lang['perm.delete_snippet_desc'] = 'スニペットを削除する';
$_lang['perm.delete_template_desc'] = 'テンプレートを削除する';
$_lang['perm.delete_tv_desc'] = 'テンプレート変数を削除する';
$_lang['perm.delete_user_desc'] = 'ユーザーを削除する';
$_lang['perm.directory_chmod_desc'] = '物理フォルダの権限を変更する';
$_lang['perm.directory_create_desc'] = '物理フォルダを作成する';
$_lang['perm.directory_list_desc'] = '物理フォルダのサブフォルダ一覧';
$_lang['perm.directory_remove_desc'] = '物理フォルダを削除する';
$_lang['perm.directory_update_desc'] = '物理フォルダの名前を変更する';
$_lang['perm.edit_category_desc'] = 'カテゴリを編集する';
$_lang['perm.edit_chunk_desc'] = 'チャンクを編集する';
$_lang['perm.edit_context_desc'] = 'コンテキストを編集する';
$_lang['perm.edit_document_desc'] = 'リソースを編集する';
$_lang['perm.edit_locked_desc'] = 'ロックの上書きを許可し、ロックされたリソースを編集する';
$_lang['perm.edit_plugin_desc'] = 'プラグインを編集する';
$_lang['perm.edit_propertyset_desc'] = 'プロパティセットを編集する';
$_lang['perm.edit_role_desc'] = 'ロールを編集する';
$_lang['perm.edit_snippet_desc'] = 'スニペットを編集する';
$_lang['perm.edit_template_desc'] = 'テンプレートを編集する';
$_lang['perm.edit_tv_desc'] = 'テンプレート変数を編集する';
$_lang['perm.edit_user_desc'] = 'ユーザーを編集する';
$_lang['perm.element_tree_desc'] = '左のナビゲーションにエレメントのツリーを表示する機能';
$_lang['perm.empty_cache_desc'] = 'サイトのキャッシュを空にする';
$_lang['perm.error_log_erase_desc'] = 'エラーログを消す';
$_lang['perm.error_log_view_desc'] = 'エラーログを表示する';
$_lang['perm.export_static_desc'] = 'サイトを静的HTMLにエクスポートする';
$_lang['perm.file_list_desc'] = '指定した物理フォルダのファイルを一覧にする';
$_lang['perm.file_manager_desc'] = 'ファイルマネージャー機能を使用する';
$_lang['perm.file_remove_desc'] = '物理ファイルを削除する';
$_lang['perm.file_tree_desc'] = '左のナビゲーションにファイルのツリーを表示する';
$_lang['perm.file_update_desc'] = '物理ファイルのコンテンツを更新する';
$_lang['perm.file_upload_desc'] = 'フォルダへファイルをアップロードする';
$_lang['perm.file_view_desc'] = 'ファイルのコンテンツを表示する';
$_lang['perm.flush_sessions_desc'] = 'サイトのセッションを削除することが可能';
$_lang['perm.frames_desc'] = '全てにおいてMODX管理画面UIを使用する';
$_lang['perm.help_desc'] = 'ヘルプページを表示する';
$_lang['perm.home_desc'] = 'ウェルカムページ(ダッシュボード)を表示する';
$_lang['perm.import_static_desc'] = 'インポートページを表示・利用する';
$_lang['perm.languages_desc'] = '語彙の言語を表示・編集する';
$_lang['perm.lexicons_desc'] = 'レキシコン管理機能を表示・編集する';
$_lang['perm.list_desc'] = 'オブジェクトを「一覧」にする基本的な権限。一覧とはオブジェクトを集める手段を意味する。';
$_lang['perm.load_desc'] = 'オブジェクトを「読み込む」基本的な権限、または全てのインスタンスを返却できる権限。';
$_lang['perm.logout_desc'] = 'ログアウトできます';
$_lang['perm.logs_desc'] = 'エラーログや管理画面操作ログなどを表示する';
$_lang['perm.menus_desc'] = 'トップメニューのアイテムを編集・保存する';
$_lang['perm.messages_desc'] = 'メッセージの送信または表示を行う';
$_lang['perm.move_desc'] = 'オブジェクトでの基本的な「移動」動作';
$_lang['perm.namespaces_desc'] = 'ネームスペースを表示・編集する';
$_lang['perm.new_category_desc'] = '新しいカテゴリを作成する';
$_lang['perm.new_chunk_desc'] = '新しいチャンクを作成する';
$_lang['perm.new_context_desc'] = '新しいコンテキストを作成する';
$_lang['perm.new_document_desc'] = '新しいリソースを作成する';
$_lang['perm.new_document_in_root_desc'] = 'rootレベルでリソースを作成可能';
$_lang['perm.new_plugin_desc'] = '新しいプラグインを作成する';
$_lang['perm.new_propertyset_desc'] = '新しいプロパティセットを作成する';
$_lang['perm.new_role_desc'] = '新しいロールを作成する';
$_lang['perm.new_snippet_desc'] = '新しいスニペットを作成する';
$_lang['perm.new_template_desc'] = '新しいテンプレートを作成する';
$_lang['perm.new_tv_desc'] = '新しいテンプレート変数を作成する';
$_lang['perm.new_user_desc'] = '新しいユーザーを作成する';
$_lang['perm.packages_desc'] = 'パッケージ管理システムで、転送パッケージを使用する';
$_lang['perm.property_sets_desc'] = 'プロパティとプロパティセットの表示と編集を行う';
$_lang['perm.providers_desc'] = 'サイト上でプロバイダーの表示と編集を行う';
$_lang['perm.publish_desc'] = 'オブジェクトでの基本的な「公開」動作';
$_lang['perm.publish_document_desc'] = 'リソースを公開または非公開にする';
$_lang['perm.purge_deleted_desc'] = 'ゴミ箱を空にする';
$_lang['perm.remove_desc'] = 'オブジェクトを削除する基本的な権限';
$_lang['perm.remove_locks_desc'] = 'サイト上に存在している全てのロックを削除する';
$_lang['perm.resource_tree_desc'] = '左のナビゲーションにリソースのツリーを表示する';
$_lang['perm.save_desc'] = 'オブジェクトの基本的な保存権限';
$_lang['perm.save_category_desc'] = 'カテゴリを保存する';
$_lang['perm.save_chunk_desc'] = 'チャンクを保存する';
$_lang['perm.save_context_desc'] = 'コンテキストを保存する';
$_lang['perm.save_document_desc'] = 'リソースを保存する';
$_lang['perm.save_plugin_desc'] = 'プラグインを保存する';
$_lang['perm.save_propertyset_desc'] = 'プロパティセットを保存する';
$_lang['perm.save_role_desc'] = 'ロールを保存する';
$_lang['perm.save_snippet_desc'] = 'スニペットを保存する';
$_lang['perm.save_template_desc'] = 'テンプレートを保存する';
$_lang['perm.save_tv_desc'] = 'テンプレート変数を保存する';
$_lang['perm.save_user_desc'] = 'ユーザーを保存する';
$_lang['perm.search_desc'] = '検索ページを使用する';
$_lang['perm.settings_desc'] = 'システム設定の表示と編集を行う';
$_lang['perm.source_delete_desc'] = 'To delete a Media Source.';
$_lang['perm.source_edit_desc'] = 'To edit a Media Source.';
$_lang['perm.source_save_desc'] = 'To create or save a Media Source.';
$_lang['perm.source_view_desc'] = 'To view and list Media Sources.';
$_lang['perm.sources_desc'] = 'To manage Media Sources and Media Source Types.';
$_lang['perm.steal_lock_desc'] = 'リソースからロックを「横取り」または削除する';
$_lang['perm.steal_locks_desc'] = 'リソースの現在のロックをうがわいてロックを「横取り」する';
$_lang['perm.tree_show_resource_ids_desc'] = 'Show the IDs in the Resource tree.';
$_lang['perm.tree_show_element_ids_desc'] = 'Show the IDs in the Elements tree.';
$_lang['perm.undelete_desc'] = 'オブジェクトを復活する基本的な権限';
$_lang['perm.undelete_document_desc'] = 'リソースを復活する';
$_lang['perm.unlock_element_properties_desc'] = 'エレメントでデフォルトのプロパティを編集可能';
$_lang['perm.unpublish_desc'] = 'リソースを非公開にする';
$_lang['perm.unpublish_document_desc'] = 'リソースを非公開にする';
$_lang['perm.view_desc'] = 'オブジェクトを表示する基本的な権限';
$_lang['perm.view_category_desc'] = 'カテゴリを表示する';
$_lang['perm.view_chunk_desc'] = 'チャンクを表示する';
$_lang['perm.view_context_desc'] = 'コンテキストを表示する';
$_lang['perm.view_document_desc'] = 'リソースを表示する';
$_lang['perm.view_element_desc'] = 'エレメントまたはエレメントクラスの一覧を取得する';
$_lang['perm.view_eventlog_desc'] = 'イベントログを表示する';
$_lang['perm.view_offline_desc'] = 'ステータスがオフラインのときにサイトを表示することが可能';
$_lang['perm.view_plugin_desc'] = 'プラグインを表示する';
$_lang['perm.view_propertyset_desc'] = 'プロパティセットを表示する';
$_lang['perm.view_role_desc'] = 'ロールを表示する';
$_lang['perm.view_snippet_desc'] = 'スニペットを表示する';
$_lang['perm.view_sysinfo_desc'] = 'システム情報ページを表示する';
$_lang['perm.view_template_desc'] = 'テンプレートを表示する';
$_lang['perm.view_tv_desc'] = 'テンプレート変数を表示する';
$_lang['perm.view_unpublished_desc'] = '非公開のリソースを表示する';
$_lang['perm.view_user_desc'] = 'ユーザーを表示する';
$_lang['perm.workspaces_desc'] = 'パッケージ管理を利用する';
